=======================
Django Chuck Changelog
=======================

0.3.0
-----

* Support for travis-ci and tox by msabramo


0.2.3
-----

* execute_in_project can now execute interactive commands
* requirements file that will get installed configurable via parameter and settings
* bugfixing virtualenvwrapper support on Ubuntu / Debian Linux
